@@ -46,6 +46,15 @@ Note that this distribution’s interface can still change. If you decide
 to use CBOR::PP in your project, please always check the changelog before
 upgrading.
 
+=head1 FRACTIONAL (FLOATING-POINT) NUMBERS
+
+Floating-point numbers are encoded in CBOR as IEEE 754 half-, single-,
+or double-precision. If your Perl is compiled to use “long double”
+floating-point numbers, you may see rounding errors when converting
+to/from CBOR. If that’s a problem for you, append an empty string to
+your floating-point numbers, which will cause CBOR::PP to encode
+them as strings.
+
 =head1 SEE ALSO
 
 L<CBOR::Free> is a B<much> faster, XS-based encoder/decoder.
@@ -67,7 +76,7 @@ This code is licensed under the same license as Perl itself.
 
 #----------------------------------------------------------------------
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use CBOR::PP::Encode ();
 use CBOR::PP::Decode ();
